@@ -4,7 +4,7 @@
 
  Copyright (c) 1996 Kolossvary Tamas <thomas@tvnet.hu>
  Copyright (c) 1997 John Zero <john@graphisoft.hu>
- Copyright (c) 2005 William McBrine <wmcbrine@users.sf.net>
+ Copyright (c) 2007 William McBrine <wmcbrine@users.sf.net>
 
  Distributed under the GNU General Public License.
  For details, see the file COPYING in the parent directory. */
@@ -187,11 +187,7 @@ void Win::wscroll(int i)
 void Win::cursor_on()
 {
 	leaveok(win, FALSE);
-#ifdef PDCURSKLUDGE
-	PDC_set_cursor_mode(curs_start, curs_end);
-#else
 	curs_set(1);
-#endif
 }
 
 void Win::cursor_off()
@@ -215,7 +211,7 @@ int Win::inkey()
 {
 	// Wait until key pressed, SIGWINCH received, or 5 seconds
 
-#ifdef __PDCURSES__
+#ifdef PDCURSES
 	nodelay(win, TRUE);
 #else
 # ifndef NCURSES_VERSION
@@ -251,24 +247,12 @@ void Win::clreol(int y, int x)
 #ifdef USE_MOUSE
 int Win::xstart()
 {
-# ifndef NCURSES_MOUSE_VERSION
 	return getbegx(win);
-# else
-	int x, y;
-	getbegyx(win, y, x);
-	return x;
-# endif
 }
 
 int Win::ystart()
 {
-# ifndef NCURSES_MOUSE_VERSION
 	return getbegy(win);
-# else
-	int x, y;
-	getbegyx(win, y, x);
-	return y;
-# endif
 }
 #endif
 
@@ -285,7 +269,7 @@ ShadowedWin::ShadowedWin(int height, int width, int topline, coltype backg,
 	int i, j;
 	chtype *right, *lower;
 # ifndef NCURSES_VERSION
-#  ifdef __PDCURSES__
+#  ifdef PDCURSES
 	WINDOW *&newscr = curscr;
 #  else
 	WINDOW *&newscr = stdscr;
@@ -448,7 +432,7 @@ int ShadowedWin::getstring(int y, int x, char *string, int maxlen,
 #ifdef USE_MOUSE
 		case MM_MOUSE:
 			mm_mouse_get();
-			if (mouse_event.bstate & BUTTON3_CLICKED)
+			if (mm_mouse_event.bstate & BUTTON3_CLICKED)
 				end = 1;
 			else
 				end = 2;
@@ -753,32 +737,32 @@ bool ListWindow::KeyHandle(int key)
 		{
 		    int begx = list->xstartinfo(), begy = list->ystartinfo();
 
-		    if ( ((mouse_event.x < begx) || (mouse_event.x >
-			(begx + list_max_x))) || ((mouse_event.y <
-			(begy - 1)) || (mouse_event.y >
+		    if ( ((mm_mouse_event.x < begx) || (mm_mouse_event.x >
+			(begx + list_max_x))) || ((mm_mouse_event.y <
+			(begy - 1)) || (mm_mouse_event.y >
 			(begy + list_max_y))) ) {
 			    draw = false;
 			    end = extrakeys(key);
 		    } else {
-			mouse_event.y -= begy;
-			if (-1 == mouse_event.y)
+			mm_mouse_event.y -= begy;
+			if (-1 == mm_mouse_event.y)
 			    Move(KEY_UP);
 			else
-			    if (list_max_y == mouse_event.y)
+			    if (list_max_y == mm_mouse_event.y)
 				Move(KEY_DOWN);
 			    else
 				if ((begx + list_max_x) ==
-				    mouse_event.x) {
-					if (mouse_event.y > oldHigh)
+				    mm_mouse_event.x) {
+					if (mm_mouse_event.y > oldHigh)
 					    Move(KEY_NPAGE);
 					else
-					    if (mouse_event.y < oldHigh)
+					    if (mm_mouse_event.y < oldHigh)
 						Move(KEY_PPAGE);
 				} else {
-					bool select = (mouse_event.bstate &
+					bool select = (mm_mouse_event.bstate &
 					    BUTTON1_DOUBLE_CLICKED) || (active
-					    == (position + mouse_event.y));
-					active = position + mouse_event.y;
+					    == (position + mm_mouse_event.y));
+					active = position + mm_mouse_event.y;
 					if (select) {
 						draw = false;
 						end = ui->select();
